@@ -1,4 +1,4 @@
-## Copyright (C) 2011 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2011-2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -14,7 +14,7 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{info} =} residmin_stat (@var{f}, @var{p}, @var{x}, @var{y}, @var{settings})
+## @deftypefn {Function File} {@var{info} =} curvefit_stat (@var{f}, @var{p}, @var{x}, @var{y}, @var{settings})
 ##
 ## Frontend for computation of statistics for fitting of values,
 ## computed by a model function, to observed values.
@@ -47,7 +47,7 @@ function ret = curvefit_stat (f, pfin, x, y, settings)
     ## sometime in 3.3.54+, if I remember right
     optimget = @ __optimget__;
   endif
-  if (! isempty (dfdp = optimget (settings, "dfdp")) && \
+  if (! isempty (dfdp = optimget (settings, "dfdp")) && ...
       ! (ismatrix (dfdp) && ! ischar (dfdp)))
     if (ischar (dfdp))
       dfdp = str2func (dfdp);
@@ -58,7 +58,7 @@ function ret = curvefit_stat (f, pfin, x, y, settings)
     f = @ (p) f (p, x);
   endif
 
-  ret = __residmin_stat__ \
+  ret = __residmin_stat__ ...
       (f, pfin, settings, struct ("observations", y));
 
 endfunction
