@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -63,7 +63,7 @@ function [p, fy, cvg, outp] = nonlin_curvefit (f, pin, x, y, settings)
     settings.dfdp =  @ (p, varargin) dfdp (p, x, varargin{:});
   endif
 
-  [p, fy, cvg, outp] = __nonlin_residmin__ \
+  [p, fy, cvg, outp] = __nonlin_residmin__ ...
       (@ (p) f (p, x), pin, settings, struct ("observations", y));
 
   fy += y;
