@@ -1,4 +1,4 @@
-## Copyright (C) 2012 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2012, 2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -58,13 +58,12 @@
 ## described in separate sections below.
 ##
 ## @code{objf_grad}: Function computing the gradient of the objective
-## function with respect to the parameters, assuming residuals are
-## reshaped to a vector. Default: finite differences. Will be called
-## with the column vector of parameters and an informational structure
-## as arguments. The structure has the fields @code{f}: value of
-## objective function for current parameters, @code{fixed}: logical
-## vector indicating which parameters are not optimized, so these
-## partial derivatives need not be computed and can be set to zero,
+## function with respect to the parameters. Will be called with the
+## column vector of parameters and an informational structure as
+## arguments. The structure has the fields @code{f}: value of objective
+## function for current parameters, @code{fixed}: logical vector
+## indicating which parameters are not optimized, so these partial
+## derivatives need not be computed and can be set to zero,
 ## @code{diffp}, @code{diff_onesided}, @code{lbound}, @code{ubound}:
 ## identical to the user settings of this name, @code{plabels}:
 ## 1-dimensional cell-array of column-cell-arrays, each column with
@@ -108,6 +107,13 @@
 ## @code{cstep}: scalar step size for complex step derivative
 ## approximation. Default: 1e-20.
 ##
+## @code{parallel_local}: logical scalar, default: false. Estimate
+## gradient of objective function and of constraints in parallel
+## processes. Works for default finite difference gradient function and
+## for complex step derivatives. Due to overhead, a speed advantage can
+## only be expected if objective function or constraint functions are
+## time consuming enough.
+##
 ## @code{fixed}: logical column vector indicating which parameters
 ## should not be optimized, but kept to their inital value. Fixing is
 ## done independently of the backend, but the backend may choose to fix
@@ -137,7 +143,7 @@
 ## if @code{idx} is not given. It may choose to return only the indexed
 ## constraints if @code{idx} is given (so computation of the other
 ## constraints can be spared); in this case, the additional setting
-## @code{inequc_f_idx} has to be set to @code{true}. In gradient
+## @code{f_inequc_idx} has to be set to @code{true}. In gradient
 ## determination, this function may be called with an informational
 ## third argument, whose content depends on the function for gradient
 ## determination. If a second entry for general inequality constraints
@@ -147,7 +153,7 @@
 ## called with 3 arguments since it has an additional argument
 ## @code{idx}, a logical index, at second position, indicating which
 ## rows of the jacobian must be returned (if the function chooses to
-## return only indexed rows, the additional setting @code{inequc_df_idx}
+## return only indexed rows, the additional setting @code{df_inequc_idx}
 ## has to be set to @code{true}). 2) the default jacobian function calls
 ## @code{h} with 3 arguments, since the argument @code{idx} is also
 ## supplied. Note that specifying linear constraints as general
@@ -156,7 +162,7 @@
 ##
 ## @code{equc}: Equality constraints. Specified the same way as
 ## inequality constraints (see @code{inequc}). The respective additional
-## settings are named @code{equc_f_idx} and @code{equc_df_idx}.
+## settings are named @code{f_equc_idx} and @code{df_equc_idx}.
 ##
 ## @code{cpiv}: Function for complementary pivoting, usable in
 ## algorithms for constraints. Default: @ cpiv_bard. Only the default
@@ -201,8 +207,8 @@
 ## containing the current parameters being a structure instead of a
 ## column vector. For this, a corresponding setting must be set to
 ## @code{true}: @code{objf_pstruct} (objective function),
-## @code{objf_grad_pstruct} (gradient of objective function),
-## @code{objf_hessian_pstruct} (hessian of objective function),
+## @code{grad_objf_pstruct} (gradient of objective function),
+## @code{hessian_objf_pstruct} (hessian of objective function),
 ## @code{f_inequc_pstruct} (general inequality constraints),
 ## @code{df_inequc_pstruct} (jacobian of general inequality
 ## constraints), @code{f_equc_pstruct} (general equality constraints),
@@ -332,48 +338,50 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   cstep_default = 1e-20;
 
   if (nargin == 1 && ischar (f) && strcmp (f, "defaults"))
-    p = optimset ("param_config", [], \
-		  "param_order", [], \
-		  "param_dims", [], \
-		  "f_inequc_pstruct", false, \
-		  "f_equc_pstruct", false, \
-		  "objf_pstruct", false, \
-		  "df_inequc_pstruct", false, \
-		  "df_equc_pstruct", false, \
-		  "objf_grad_pstruct", false, \
-		  "objf_hessian_pstruct", false, \
-		  "lbound", [], \
-		  "ubound", [], \
-		  "objf_grad", [], \
-		  "objf_hessian", [], \
-		  "cpiv", @ cpiv_bard, \
-		  "max_fract_change", [], \
-		  "fract_prec", [], \
-		  "diffp", [], \
-		  "diff_onesided", [], \
-		  "complex_step_derivative_objf", false, \
-		  "complex_step_derivative_inequc", false, \
-		  "complex_step_derivative_equc", false, \
-		  "cstep", cstep_default, \
-		  "fixed", [], \
-		  "inequc", [], \
-		  "equc", [], \
-                  "inequc_f_idx", false, \
-                  "inequc_df_idx", false, \
-                  "equc_f_idx", false, \
-                  "equc_df_idx", false, \
-		  "TolFun", stol_default, \
-		  "MaxIter", [], \
-		  "Display", "off", \
-		  "Algorithm", "lm_feasible", \
-		  "T_init", .01, \
-		  "T_min", 1.0e-5, \
-		  "mu_T", 1.005, \
-		  "iters_fixed_T", 10, \
-		  "max_rand_step", [], \
-		  "stoch_regain_constr", false, \
-                  "trace_steps", false, \
-                  "siman_log", false, \
+    p = optimset ("param_config", [], ...
+		  "param_order", [], ...
+		  "param_dims", [], ...
+		  "f_inequc_pstruct", false, ...
+		  "f_equc_pstruct", false, ...
+		  "objf_pstruct", false, ...
+		  "df_inequc_pstruct", false, ...
+		  "df_equc_pstruct", false, ...
+		  "grad_objf_pstruct", false, ...
+		  "hessian_objf_pstruct", false, ...
+		  "lbound", [], ...
+		  "ubound", [], ...
+		  "objf_grad", [], ...
+		  "objf_hessian", [], ...
+		  "cpiv", @ cpiv_bard, ...
+		  "max_fract_change", [], ...
+		  "fract_prec", [], ...
+		  "diffp", [], ...
+		  "diff_onesided", [], ...
+		  "complex_step_derivative_objf", false, ...
+		  "complex_step_derivative_inequc", false, ...
+		  "complex_step_derivative_equc", false, ...
+		  "cstep", cstep_default, ...
+		  "fixed", [], ...
+		  "inequc", [], ...
+		  "equc", [], ...
+                  "f_inequc_idx", false, ...
+                  "df_inequc_idx", false, ...
+                  "f_equc_idx", false, ...
+                  "df_equc_idx", false, ...
+		  "TolFun", stol_default, ...
+		  "MaxIter", [], ...
+		  "Display", "off", ...
+		  "Algorithm", "lm_feasible", ...
+                  "parallel_local", false, ... # Matlabs UseParallel
+                                # works differently
+		  "T_init", .01, ...
+		  "T_min", 1.0e-5, ...
+		  "mu_T", 1.005, ...
+		  "iters_fixed_T", 10, ...
+		  "max_rand_step", [], ...
+		  "stoch_regain_constr", false, ...
+                  "trace_steps", false, ...
+                  "siman_log", false, ...
 		  "debug", false);
     return;
   endif
@@ -404,11 +412,11 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   f_inequc_pstruct = optimget (settings, "f_inequc_pstruct", false);
   f_equc_pstruct = optimget (settings, "f_equc_pstruct", false);
   f_pstruct = optimget (settings, "objf_pstruct", false);
-  dfdp_pstruct = optimget (settings, "objf_grad_pstruct", f_pstruct);
-  hessian_pstruct = optimget (settings, "objf_hessian_pstruct", f_pstruct);
-  df_inequc_pstruct = optimget (settings, "df_inequc_pstruct", \
+  dfdp_pstruct = optimget (settings, "grad_objf_pstruct", f_pstruct);
+  hessian_pstruct = optimget (settings, "hessian_objf_pstruct", f_pstruct);
+  df_inequc_pstruct = optimget (settings, "df_inequc_pstruct", ...
 				f_inequc_pstruct);
-  df_equc_pstruct = optimget (settings, "df_equc_pstruct", \
+  df_equc_pstruct = optimget (settings, "df_equc_pstruct", ...
 			      f_equc_pstruct);
   lbound = optimget (settings, "lbound");
   ubound = optimget (settings, "ubound");
@@ -425,24 +433,24 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (do_cstep && ! isempty (dfdp))
     error ("both 'complex_step_derivative_objf' and 'objf_grad' are set");
   endif
-  do_cstep_inequc = \
+  do_cstep_inequc = ...
       optimget (settings, "complex_step_derivative_inequc", false);
-  do_cstep_equc = optimget (settings, "complex_step_derivative_equc", \
+  do_cstep_equc = optimget (settings, "complex_step_derivative_equc", ...
 			    false);
   max_rand_step = optimget (settings, "max_rand_step");
 
-  any_vector_conf = ! (isempty (lbound) && isempty (ubound) && \
-		       isempty (max_fract_change) && \
-		       isempty (fract_prec) && isempty (diffp) && \
-		       isempty (diff_onesided) && isempty (fixed) && \
+  any_vector_conf = ! (isempty (lbound) && isempty (ubound) && ...
+		       isempty (max_fract_change) && ...
+		       isempty (fract_prec) && isempty (diffp) && ...
+		       isempty (diff_onesided) && isempty (fixed) && ...
 		       isempty (max_rand_step));
 
   ## collect constraints
-  [mc, vc, f_genicstr, df_gencstr, user_df_gencstr] = \
-      __collect_constraints__ (optimget (settings, "inequc"), \
+  [mc, vc, f_genicstr, df_gencstr, user_df_gencstr] = ...
+      __collect_constraints__ (optimget (settings, "inequc"), ...
 			       do_cstep_inequc, "inequality constraints");
-  [emc, evc, f_genecstr, df_genecstr, user_df_genecstr] = \
-      __collect_constraints__ (optimget (settings, "equc"), \
+  [emc, evc, f_genecstr, df_genecstr, user_df_genecstr] = ...
+      __collect_constraints__ (optimget (settings, "equc"), ...
 			       do_cstep_equc, "equality constraints");
   mc_struct = isstruct (mc);
   emc_struct = isstruct (emc);
@@ -453,25 +461,25 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (isempty (hessian)) hessian_pstruct = false; endif
   if (isempty (f_genicstr))
     f_inequc_pstruct = false;
-  elseif (! optimget (settings, "inequc_f_idx", false))
-    f_genicstr = @ (p, varargin) apply_idx_if_given \
+  elseif (! optimget (settings, "f_inequc_idx", false))
+    f_genicstr = @ (p, varargin) apply_idx_if_given ...
         (f_genicstr (p, varargin{:}), varargin{:});
   endif
   if (isempty (f_genecstr))
     f_equc_pstruct = false;
-  elseif (! optimget (settings, "equc_f_idx", false))
-    f_genecstr = @ (p, varargin) apply_idx_if_given \
+  elseif (! optimget (settings, "f_equc_idx", false))
+    f_genecstr = @ (p, varargin) apply_idx_if_given ...
         (f_genecstr (p, varargin{:}), varargin{:});
   endif
   if (user_df_gencstr)
-    if (! optimget (settings, "inequc_df_idx", false))
+    if (! optimget (settings, "df_inequc_idx", false))
       df_gencstr = @ (varargin) df_gencstr (varargin{:})(varargin{2}, :);
     endif
   else
     df_inequc_pstruct = false;
   endif
   if (user_df_genecstr)
-    if (! optimget (settings, "equc_df_idx", false))
+    if (! optimget (settings, "df_equc_idx", false))
       df_genecstr = @ (varargin) df_genecstr (varargin{:})(varargin{2}, :);
     endif
   else
@@ -479,21 +487,21 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   endif
 
   ## some settings require a parameter order
-  if (pin_struct || ! isempty (pconf) || f_inequc_pstruct || \
-      f_equc_pstruct || f_pstruct || dfdp_pstruct || \
-      hessian_pstruct || df_inequc_pstruct || df_equc_pstruct || \
+  if (pin_struct || ! isempty (pconf) || f_inequc_pstruct || ...
+      f_equc_pstruct || f_pstruct || dfdp_pstruct || ...
+      hessian_pstruct || df_inequc_pstruct || df_equc_pstruct || ...
       mc_struct || emc_struct)
     if (isempty (pord))
       if (pin_struct)
-	if (any_vector_conf || \
-	    ! (f_pstruct && \
-	       (f_inequc_pstruct || isempty (f_genicstr)) && \
-	       (f_equc_pstruct || isempty (f_genecstr)) && \
-	       (dfdp_pstruct || isempty (dfdp)) && \
-	       (hessian_pstruct || isempty (hessian)) && \
-	       (df_inequc_pstruct || ! user_df_gencstr) && \
-	       (df_equc_pstruct || ! user_df_genecstr) && \
-	       (mc_struct || isempty (mc)) && \
+	if (any_vector_conf || ...
+	    ! (f_pstruct && ...
+	       (f_inequc_pstruct || isempty (f_genicstr)) && ...
+	       (f_equc_pstruct || isempty (f_genecstr)) && ...
+	       (dfdp_pstruct || isempty (dfdp)) && ...
+	       (hessian_pstruct || isempty (hessian)) && ...
+	       (df_inequc_pstruct || ! user_df_gencstr) && ...
+	       (df_equc_pstruct || ! user_df_genecstr) && ...
+	       (mc_struct || isempty (mc)) && ...
 	       (emc_struct || isempty (emc))))
 	  error ("no parameter order specified and constructing a parameter order from the structure of initial parameters can not be done since not all configuration or given functions are structure based");
 	else
@@ -512,15 +520,15 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     endif
     if (isempty (pdims))
       if (pin_struct)
-	pdims = cellfun \
+	pdims = cellfun ...
 	    (@ size, fields2cell (pin, pord), "UniformOutput", false);
       else
 	pdims = num2cell (ones (nnames, 2), 2);
       endif
     else
       pdims = pdims(:);
-      if (pin_struct && \
-	  ! all (cellfun (@ (x, y) prod (size (x)) == prod (y), \
+      if (pin_struct && ...
+	  ! all (cellfun (@ (x, y) prod (size (x)) == prod (y), ...
 			  struct2cell (pin), pdims)))
 	error ("given param_dims and dimensions of initial parameters do not match");
       endif
@@ -533,13 +541,13 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (any (pnel > 1))
       pnonscalar = true;
       cpnel = num2cell (pnel);
-      prepidx = cat (1, cellfun \
-		     (@ (x, n) x(ones (1, n), 1), \
-		      num2cell ((1:nnames).'), cpnel, \
+      prepidx = cat (1, cellfun ...
+		     (@ (x, n) x(ones (1, n), 1), ...
+		      num2cell ((1:nnames).'), cpnel, ...
 		      "UniformOutput", false){:});
       epord = pord(prepidx, 1);
-      psubidx = cat (1, cellfun \
-		     (@ (n) (1:n).', cpnel, \
+      psubidx = cat (1, cellfun ...
+		     (@ (n) (1:n).', cpnel, ...
 		      "UniformOutput", false){:});
     else
       pnonscalar = false; # some less expensive interfaces later
@@ -562,7 +570,7 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
   plabels = num2cell (num2cell ((1:np).'));
   if (! isempty (pord))
-    plabels = cat (2, plabels, num2cell (epord), \
+    plabels = cat (2, plabels, num2cell (epord), ...
 		   num2cell (num2cell (psubidx)));
   endif
 
@@ -586,7 +594,7 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
     ## supplement parameter names lacking in param_config
     nidx = ! isfield (pconf, pord);
-    pconf = cell2fields ({struct()}(ones (1, sum (nidx))), \
+    pconf = cell2fields ({struct()}(ones (1, sum (nidx))), ...
 			 pord(nidx), 2, pconf);
 
     pconf = structcat (1, fields2cell (pconf, pord){:});
@@ -599,9 +607,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "lbound"))
       idx = ! fieldempty (pconf, "lbound");
       if (pnonscalar)
-	lbound (idx(prepidx), 1) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).lbound}.', \
+	lbound (idx(prepidx), 1) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).lbound}.', ...
 			     cpnel(idx), "UniformOutput", false){:});
       else
 	lbound(idx, 1) = cat (1, pconf.lbound);
@@ -612,9 +620,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "ubound"))
       idx = ! fieldempty (pconf, "ubound");
       if (pnonscalar)
-	ubound (idx(prepidx), 1) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).ubound}.', \
+	ubound (idx(prepidx), 1) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).ubound}.', ...
 			     cpnel(idx), "UniformOutput", false){:});
       else
 	ubound(idx, 1) = cat (1, pconf.ubound);
@@ -626,10 +634,10 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "max_fract_change"))
       idx = ! fieldempty (pconf, "max_fract_change");
       if (pnonscalar)
-	max_fract_change(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).max_fract_change}.', \
-			     cpnel(idx), \
+	max_fract_change(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).max_fract_change}.', ...
+			     cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	max_fract_change(idx) = [pconf.max_fract_change];
@@ -639,9 +647,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "fract_prec"))
       idx = ! fieldempty (pconf, "fract_prec");
       if (pnonscalar)
-	fract_prec(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).fract_prec}.', cpnel(idx), \
+	fract_prec(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).fract_prec}.', cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	fract_prec(idx) = [pconf.fract_prec];
@@ -653,9 +661,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "diffp"))
       idx = ! fieldempty (pconf, "diffp");
       if (pnonscalar)
-	diffp(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).diffp}.', cpnel(idx), \
+	diffp(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).diffp}.', cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	diffp(idx) = [pconf.diffp];
@@ -667,10 +675,10 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "diff_onesided"))
       idx = ! fieldempty (pconf, "diff_onesided");
       if (pnonscalar)
-	diff_onesided(idx(prepidx)) = \
-	    logical \
-	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			      {pconf(idx).diff_onesided}.', cpnel(idx), \
+	diff_onesided(idx(prepidx)) = ...
+	    logical ...
+	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			      {pconf(idx).diff_onesided}.', cpnel(idx), ...
 			     "UniformOutput", false){:}));
       else
 	diff_onesided(idx) = logical ([pconf.diff_onesided]);
@@ -680,10 +688,10 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "fixed"))
       idx = ! fieldempty (pconf, "fixed");
       if (pnonscalar)
-	fixed(idx(prepidx)) = \
-	    logical \
-	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			      {pconf(idx).fixed}.', cpnel(idx), \
+	fixed(idx(prepidx)) = ...
+	    logical ...
+	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			      {pconf(idx).fixed}.', cpnel(idx), ...
 			     "UniformOutput", false){:}));
       else
 	fixed(idx) = logical ([pconf.fixed]);
@@ -695,11 +703,11 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (isfield (pconf, "max_rand_step"))
       idx = ! fieldempty (pconf, "max_rand_step");
       if (pnonscalar)
-	max_rand_step(idx(prepidx)) = \
-	    logical \
-	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
+	max_rand_step(idx(prepidx)) = ...
+	    logical ...
+	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
 			      {pconf(idx).max_rand_step}.',
-			      cpnel(idx), \
+			      cpnel(idx), ...
 			      "UniformOutput", false){:}));
       else
 	max_rand_step(idx) = logical ([pconf.max_rand_step]);
@@ -783,8 +791,8 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## initial parameters
   if (pin_struct)
     if (pnonscalar)
-      pin = cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     fields2cell (pin, pord), cpnel, \
+      pin = cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     fields2cell (pin, pord), cpnel, ...
 			     "UniformOutput", false){:});
     else
       pin = cat (1, fields2cell (pin, pord){:});
@@ -794,13 +802,13 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## objective function
   if (f_pstruct)
     if (pnonscalar)
-      f = @ (p, varargin) \
-	  f (cell2struct \
-	     (cellfun (@ reshape, mat2cell (p, ppartidx), \
-		       pdims, "UniformOutput", false), \
+      f = @ (p, varargin) ...
+	  f (cell2struct ...
+	     (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+		       pdims, "UniformOutput", false), ...
 	      pord, 1), varargin{:});
     else
-      f = @ (p, varargin) \
+      f = @ (p, varargin) ...
 	  f (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -816,19 +824,19 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   endif
   if (dfdp_pstruct)
     if (pnonscalar)
-      dfdp = @ (p, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (dfdp (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
-		       pord, 1), hook), \
+      dfdp = @ (p, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (dfdp (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
+		       pord, 1), hook), ...
 		pord){:});
     else
-      dfdp = @ (p, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (dfdp (cell2struct (num2cell (p), pord, 1), hook), \
+      dfdp = @ (p, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (dfdp (cell2struct (num2cell (p), pord, 1), hook), ...
 		pord){:});
     endif
   endif
@@ -836,15 +844,15 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## hessian of objective function
   if (hessian_pstruct)
     if (pnonscalar)
-      hessian = @ (p) \
-	  hessian_struct2mat \
-	  (hessian (cell2struct \
-		    (cellfun (@ reshape, mat2cell (p, ppartidx), \
-			      pdims, "UniformOutput", false), \
+      hessian = @ (p) ...
+	  hessian_struct2mat ...
+	  (hessian (cell2struct ...
+		    (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+			      pdims, "UniformOutput", false), ...
 		     pord, 1)), pord);
     else
-      hessian = @ (p) \
-	  hessian_struct2mat \
+      hessian = @ (p) ...
+	  hessian_struct2mat ...
 	  (hessian (cell2struct (num2cell (p), pord, 1)), pord);
     endif
   endif
@@ -852,14 +860,14 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## function for general inequality constraints
   if (f_inequc_pstruct)
     if (pnonscalar)
-      f_genicstr = @ (p, varargin) \
-	  f_genicstr (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
+      f_genicstr = @ (p, varargin) ...
+	  f_genicstr (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
 		       pord, 1), varargin{:});
     else
-      f_genicstr = @ (p, varargin) \
-	  f_genicstr \
+      f_genicstr = @ (p, varargin) ...
+	  f_genicstr ...
 	  (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -870,21 +878,21 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## jacobian of general inequality constraints
   if (df_inequc_pstruct)
     if (pnonscalar)
-      df_gencstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_gencstr \
-		(cell2struct \
-		 (cellfun (@ reshape, mat2cell (p, ppartidx), \
-			   pdims, "UniformOutput", false), pord, 1), \
-		 func, idx, hook), \
+      df_gencstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_gencstr ...
+		(cell2struct ...
+		 (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+			   pdims, "UniformOutput", false), pord, 1), ...
+		 func, idx, hook), ...
 		pord){:});
     else
-      df_gencstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_gencstr (cell2struct (num2cell (p), pord, 1), \
-			    func, idx, hook), \
+      df_gencstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_gencstr (cell2struct (num2cell (p), pord, 1), ...
+			    func, idx, hook), ...
 		pord){:});
     endif
   endif
@@ -892,14 +900,14 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## function for general equality constraints
   if (f_equc_pstruct)
     if (pnonscalar)
-      f_genecstr = @ (p, varargin) \
-	  f_genecstr (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
+      f_genecstr = @ (p, varargin) ...
+	  f_genecstr (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
 		       pord, 1), varargin{:});
     else
-      f_genecstr = @ (p, varargin) \
-	  f_genecstr \
+      f_genecstr = @ (p, varargin) ...
+	  f_genecstr ...
 	  (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -910,21 +918,21 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## jacobian of general equality constraints
   if (df_equc_pstruct)
     if (pnonscalar)
-      df_genecstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_genecstr \
-		(cell2struct \
-		 (cellfun (@ reshape, mat2cell (p, ppartidx), \
-			   pdims, "UniformOutput", false), pord, 1), \
-		 func, idx, hook), \
+      df_genecstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_genecstr ...
+		(cell2struct ...
+		 (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+			   pdims, "UniformOutput", false), pord, 1), ...
+		 func, idx, hook), ...
 		pord){:});
     else
-      df_genecstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_genecstr (cell2struct (num2cell (p), pord, 1), \
-			     func, idx, hook), \
+      df_genecstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_genecstr (cell2struct (num2cell (p), pord, 1), ...
+			     func, idx, hook), ...
 		pord){:});
     endif
   endif
@@ -954,29 +962,29 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   ## parameter-related configuration for jacobian functions
   if (dfdp_pstruct || df_inequc_pstruct || df_equc_pstruct)
     if(pnonscalar)
-      s_diffp = cell2struct \
-	  (cellfun (@ reshape, mat2cell (diffp, ppartidx), \
+      s_diffp = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (diffp, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_diff_onesided = cell2struct \
-	  (cellfun (@ reshape, mat2cell (diff_onesided, ppartidx), \
+      s_diff_onesided = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (diff_onesided, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_lbound = cell2struct \
-	  (cellfun (@ reshape, mat2cell (lbound, ppartidx), \
+      s_orig_lbound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (lbound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_ubound = cell2struct \
-	  (cellfun (@ reshape, mat2cell (ubound, ppartidx), \
+      s_orig_ubound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (ubound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_plabels = cell2struct \
-	  (num2cell \
-	   (cat (2, cellfun \
-		 (@ (x) cellfun \
-		  (@ reshape, mat2cell (cat (1, x{:}), ppartidx), \
-		   pdims, "UniformOutput", false), \
-		  num2cell (plabels, 1), "UniformOutput", false){:}), \
-	    2), \
+      s_plabels = cell2struct ...
+	  (num2cell ...
+	   (cat (2, cellfun ...
+		 (@ (x) cellfun ...
+		  (@ reshape, mat2cell (cat (1, x{:}), ppartidx), ...
+		   pdims, "UniformOutput", false), ...
+		  num2cell (plabels, 1), "UniformOutput", false){:}), ...
+	    2), ...
 	   pord, 1);
-      s_orig_fixed = cell2struct \
-	  (cellfun (@ reshape, mat2cell (fixed, ppartidx), \
+      s_orig_fixed = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (fixed, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
     else
       s_diffp = cell2struct (num2cell (diffp), pord, 1);
@@ -1053,6 +1061,7 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   endif
 
   #### collect remaining settings
+  parallel_local = optimget (settings, "parallel_local", false);
   hook.MaxIter = optimget (settings, "MaxIter");
   if (ischar (hook.cpiv = optimget (settings, "cpiv", @ cpiv_bard)))
     hook.cpiv = str2func (hook.cpiv);
@@ -1063,11 +1072,11 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   hook.siman.T_min = optimget (settings, "T_min", 1.0e-5);
   hook.siman.mu_T = optimget (settings, "mu_T", 1.005);
   hook.siman.iters_fixed_T = optimget (settings, "iters_fixed_T", 10);
-  hook.stoch_regain_constr = \
+  hook.stoch_regain_constr = ...
       optimget (settings, "stoch_regain_constr", false);
-  hook.trace_steps = \
+  hook.trace_steps = ...
       optimget (settings, "trace_steps", false);
-  hook.siman_log = \
+  hook.siman_log = ...
       optimget (settings, "siman_log", false);
   backend = optimget (settings, "Algorithm", "lm_feasible");
   backend = map_matlab_algorithm_names (backend);
@@ -1084,38 +1093,38 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   nonfixed = ! fixed;
   if (any (fixed))
     ## backend (returned values and initial parameters)
-    backend = @ (f, pin, hook) \
+    backend = @ (f, pin, hook) ...
 	backend_wrapper (backend, fixed, f, pin, hook);
 
     ## objective function
     f = @ (p, varargin) f (assign (pin, nonfixed, p), varargin{:});
 
     ## gradient of objective function
-    dfdp = @ (p, hook) \
+    dfdp = @ (p, hook) ...
 	dfdp (assign (pin, nonfixed, p), hook)(nonfixed);
 
     ## hessian of objective function
     if (! isempty (hessian))
-      hessian = @ (p) \
+      hessian = @ (p) ...
 	  hessian (assign (pin, nonfixed, p))(nonfixed, nonfixed);
     endif
     
     ## function for general inequality constraints
-    f_genicstr = @ (p, varargin) \
+    f_genicstr = @ (p, varargin) ...
 	f_genicstr (assign (pin, nonfixed, p), varargin{:});
     
     ## jacobian of general inequality constraints
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (assign (pin, nonfixed, p), func, idx, hook) \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (assign (pin, nonfixed, p), func, idx, hook) ...
 	(:, nonfixed);
 
     ## function for general equality constraints
-    f_genecstr = @ (p, varargin) \
+    f_genecstr = @ (p, varargin) ...
 	f_genecstr (assign (pin, nonfixed, p), varargin{:});
 
     ## jacobian of general equality constraints
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (assign (pin, nonfixed, p), func, idx, hook) \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (assign (pin, nonfixed, p), func, idx, hook) ...
 	(:, nonfixed);
 
     ## linear inequality constraints
@@ -1140,67 +1149,72 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
   ## gradient of objective function
   if (dfdp_pstruct)
-    dfdp = @ (p, hook) \
-	dfdp (p, cell2fields \
-	      ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		s_orig_ubound, s_plabels, \
-		cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-			    1, s_orig_fixed), cstep}, \
-	       {"diffp", "diff_onesided", "lbound", "ubound", \
-		"plabels", "fixed", "h"}, \
+    dfdp = @ (p, hook) ...
+	dfdp (p, cell2fields ...
+	      ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		s_orig_ubound, s_plabels, ...
+		cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+			    1, s_orig_fixed), ...
+                cstep, parallel_local}, ...
+	       {"diffp", "diff_onesided", "lbound", "ubound", ...
+		"plabels", "fixed", "h", "parallel_local"}, ...
 	       2, hook));
   else
-    dfdp = @ (p, hook) \
-	dfdp (p, cell2fields \
-	      ({diffp, diff_onesided, orig_lbound, orig_ubound, \
-		plabels, assign(orig_fixed, nonfixed, hook.fixed), \
-		cstep}, \
-	       {"diffp", "diff_onesided", "lbound", "ubound", \
-		"plabels", "fixed", "h"}, \
+    dfdp = @ (p, hook) ...
+	dfdp (p, cell2fields ...
+	      ({diffp, diff_onesided, orig_lbound, orig_ubound, ...
+		plabels, assign(orig_fixed, nonfixed, hook.fixed), ...
+		cstep, parallel_local}, ...
+	       {"diffp", "diff_onesided", "lbound", "ubound", ...
+		"plabels", "fixed", "h", "parallel_local"}, ...
 	       2, hook));
   endif
 
   ## jacobian of general inequality constraints
   if (df_inequc_pstruct)
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (p, func, idx, cell2fields \
-		    ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		      s_orig_ubound, s_plabels, \
-		      cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-				  1, s_orig_fixed), cstep}, \
-		     {"diffp", "diff_onesided", "lbound", "ubound", \
-		      "plabels", "fixed", "h"}, \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (p, func, idx, cell2fields ...
+		    ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		      s_orig_ubound, s_plabels, ...
+		      cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+				  1, s_orig_fixed), ...
+                      cstep, parallel_local}, ...
+		     {"diffp", "diff_onesided", "lbound", "ubound", ...
+		      "plabels", "fixed", "h", "parallel_local"}, ...
 		     2, hook));
   else
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (p, func, idx, cell2fields \
-		    ({diffp, diff_onesided, orig_lbound, \
-		      orig_ubound, plabels, \
-		      assign(orig_fixed, nonfixed, hook.fixed), cstep}, \
-		     {"diffp", "diff_onesided", "lbound", "ubound", \
-		      "plabels", "fixed", "h"}, \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (p, func, idx, cell2fields ...
+		    ({diffp, diff_onesided, orig_lbound, ...
+		      orig_ubound, plabels, ...
+		      assign(orig_fixed, nonfixed, hook.fixed), ...
+                      cstep, parallel_local}, ...
+		     {"diffp", "diff_onesided", "lbound", "ubound", ...
+		      "plabels", "fixed", "h", "parallel_local"}, ...
 		     2, hook));
   endif
 
   ## jacobian of general equality constraints
   if (df_equc_pstruct)
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (p, func, idx, cell2fields \
-		     ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		       s_orig_ubound, s_plabels, \
-		       cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-				   1, s_orig_fixed), cstep}, \
-		      {"diffp", "diff_onesided", "lbound", "ubound", \
-		       "plabels", "fixed", "h"}, \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (p, func, idx, cell2fields ...
+		     ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		       s_orig_ubound, s_plabels, ...
+		       cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+				   1, s_orig_fixed), ...
+                       cstep, parallel_local}, ...
+		      {"diffp", "diff_onesided", "lbound", "ubound", ...
+		       "plabels", "fixed", "h", "parallel_local"}, ...
 		      2, hook));
   else
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (p, func, idx, cell2fields \
-		     ({diffp, diff_onesided, orig_lbound, \
-		       orig_ubound, plabels, \
-		       assign(orig_fixed, nonfixed, hook.fixed), cstep}, \
-		      {"diffp", "diff_onesided", "lbound", "ubound", \
-		       "plabels", "fixed", "h"}, \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (p, func, idx, cell2fields ...
+		     ({diffp, diff_onesided, orig_lbound, ...
+		       orig_ubound, plabels, ...
+		       assign(orig_fixed, nonfixed, hook.fixed), ...
+                       cstep, parallel_local}, ...
+		      {"diffp", "diff_onesided", "lbound", "ubound", ...
+		       "plabels", "fixed", "h", "parallel_local"}, ...
 		      2, hook));
   endif
 
@@ -1223,41 +1237,41 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
     if (n_genicstr > 0)
       nidxi = 1 : n_genicstr;
       nidxe = n_genicstr + 1 : n_genicstr + n_genecstr;
-      f_gencstr = @ (p, idx, varargin) \
-	  cat (1, \
-	       f_genicstr (p, idx(nidxi), varargin{:}), \
+      f_gencstr = @ (p, idx, varargin) ...
+	  cat (1, ...
+	       f_genicstr (p, idx(nidxi), varargin{:}), ...
 	       f_genecstr (p, idx(nidxe), varargin{:}));
-      df_gencstr = @ (p, idx, hook) \
-	  cat (1, \
-	       df_gencstr (p, @ (p, varargin) \
-			   possibly_pstruct_f_genicstr \
-			   (p, idx(nidxi), varargin{:}), \
-			   idx(nidxi), \
-			   setfield (hook, "f", \
-				     hook.f(nidxi(idx(nidxi))))), \
-	       df_genecstr (p, @ (p, varargin) \
-			    possibly_pstruct_f_genecstr \
-			    (p, idx(nidxe), varargin{:}), \
-			    idx(nidxe), \
-			    setfield (hook, "f", \
+      df_gencstr = @ (p, idx, hook) ...
+	  cat (1, ...
+	       df_gencstr (p, @ (p, varargin) ...
+			   possibly_pstruct_f_genicstr ...
+			   (p, idx(nidxi), varargin{:}), ...
+			   idx(nidxi), ...
+			   setfield (hook, "f", ...
+				     hook.f(nidxi(idx(nidxi))))), ...
+	       df_genecstr (p, @ (p, varargin) ...
+			    possibly_pstruct_f_genecstr ...
+			    (p, idx(nidxe), varargin{:}), ...
+			    idx(nidxe), ...
+			    setfield (hook, "f", ...
 				      hook.f(nidxe(idx(nidxe))))));
     else
       f_gencstr = f_genecstr;
-      df_gencstr = @ (p, idx, hook) \
-	  df_genecstr (p, \
-		       @ (p, varargin) \
-		       possibly_pstruct_f_genecstr \
-		       (p, idx, varargin{:}), \
-		       idx, \
+      df_gencstr = @ (p, idx, hook) ...
+	  df_genecstr (p, ...
+		       @ (p, varargin) ...
+		       possibly_pstruct_f_genecstr ...
+		       (p, idx, varargin{:}), ...
+		       idx, ...
 		       setfield (hook, "f", hook.f(idx)));
     endif
   else
     f_gencstr = f_genicstr;
-    df_gencstr = @ (p, idx, hook) \
-	df_gencstr (p, \
-		    @ (p, varargin) \
-		    possibly_pstruct_f_genicstr (p, idx, varargin{:}), \
-		    idx, \
+    df_gencstr = @ (p, idx, hook) ...
+	df_gencstr (p, ...
+		    @ (p, varargin) ...
+		    possibly_pstruct_f_genicstr (p, idx, varargin{:}), ...
+		    idx, ...
 		    setfield (hook, "f", hook.f(idx)));
   endif    
   n_gencstr = n_genicstr + n_genecstr;
@@ -1267,15 +1281,15 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
   if (n_gencstr > 0)
     nidxl = 1:n_lincstr;
     nidxh = n_lincstr + 1 : n_lincstr + n_gencstr;
-    f_cstr = @ (p, idx, varargin) \
-	cat (1, \
-	     mc(:, idx(nidxl)).' * p + vc(idx(nidxl), 1), \
+    f_cstr = @ (p, idx, varargin) ...
+	cat (1, ...
+	     mc(:, idx(nidxl)).' * p + vc(idx(nidxl), 1), ...
 	     f_gencstr (p, idx(nidxh), varargin{:}));
-    df_cstr = @ (p, idx, hook) \
-	cat (1, \
-	     mc(:, idx(nidxl)).', \
-	     df_gencstr (p, idx(nidxh), \
-			 setfield (hook, "f", \
+    df_cstr = @ (p, idx, hook) ...
+	cat (1, ...
+	     mc(:, idx(nidxl)).', ...
+	     df_gencstr (p, idx(nidxh), ...
+			 setfield (hook, "f", ...
 				   hook.f(nidxh))));
   else
     f_cstr = @ (p, idx, varargin) mc(:, idx).' * p + vc(idx, 1);
@@ -1330,9 +1344,9 @@ function [p, objf, cvg, outp] = nonlin_min (f, pin, settings)
 
   if (pin_struct)
     if (pnonscalar)
-      p = cell2struct \
-	  (cellfun (@ reshape, mat2cell (p, ppartidx), \
-		    pdims, "UniformOutput", false), \
+      p = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+		    pdims, "UniformOutput", false), ...
 	   pord, 1);
     else
       p = cell2struct (num2cell (p), pord, 1);
@@ -1382,7 +1396,7 @@ endfunction
 
 function m = hessian_struct2mat (s, pord)
 
-  m = cell2mat (fields2cell \
+  m = cell2mat (fields2cell ...
 		(structcat (1, NA, fields2cell (s, pord){:}), pord));
 
   idx = isna (m);
