@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -103,6 +103,13 @@
 ## @code{cstep}: scalar step size for complex step derivative
 ## approximation. Default: 1e-20.
 ##
+## @code{parallel_local}: logical scalar, default: false. Estimate
+## Jacobians of model function and of constraints in parallel processes.
+## Works for default finite difference Jacobian function and for complex
+## step derivatives. Due to overhead, a speed advantage can only be
+## expected if model function or constraint functions are time consuming
+## enough.
+##
 ## @code{fixed}: logical column vector indicating which parameters
 ## should not be optimized, but kept to their inital value. Fixing is
 ## done independently of the backend, but the backend may choose to fix
@@ -132,7 +139,7 @@
 ## @code{idx} is not given. It may choose to return only the indexed
 ## constraints if @code{idx} is given (so computation of the other
 ## constraints can be spared); in this case, the additional setting
-## @code{inequc_f_idx} has to be set to @code{true}. In gradient
+## @code{f_inequc_idx} has to be set to @code{true}. In gradient
 ## determination, this function may be called with an informational
 ## third argument, whose content depends on the function for gradient
 ## determination. If a second entry for general inequality constraints
@@ -142,7 +149,7 @@
 ## called with 3 arguments since it has an additional argument
 ## @code{idx}, a logical index, at second position, indicating which
 ## rows of the jacobian must be returned (if the function chooses to
-## return only indexed rows, the additional setting @code{inequc_df_idx}
+## return only indexed rows, the additional setting @code{df_inequc_idx}
 ## has to be set to @code{true}). 2) the default jacobian function calls
 ## @code{h} with 3 arguments, since the argument @code{idx} is also
 ## supplied. Note that specifying linear constraints as general
@@ -202,7 +209,7 @@
 ## Each user-supplied function can be called with the argument
 ## containing the current parameters being a structure instead of a
 ## column vector. For this, a corresponding setting must be set to
-## @code{true}: @code{f_pstruct} (model function), @code{dfdp_pstruct}
+## @code{true}: @code{f_pstruct} (model function), @code{df_pstruct}
 ## (jacobian of model function), @code{f_inequc_pstruct} (general
 ## inequality constraints), @code{df_inequc_pstruct} (jacobian of
 ## general inequality constraints), @code{f_equc_pstruct} (general
