@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 ## disabled PKG_ADD: __all_opts__ ("__nonlin_residmin__");
 
-function [p, resid, cvg, outp] = \
+function [p, resid, cvg, outp] = ...
       __nonlin_residmin__ (f, pin, settings, hook)
 
   if (compare_versions (version (), "3.3.55", "<"))
@@ -45,41 +45,43 @@ function [p, resid, cvg, outp] = \
   cstep_default = 1e-20;
 
   if (nargin == 1 && ischar (f) && strcmp (f, "defaults"))
-    p = optimset ("param_config", [], \
-		  "param_order", [], \
-		  "param_dims", [], \
-		  "f_inequc_pstruct", false, \
-		  "f_equc_pstruct", false, \
-		  "f_pstruct", false, \
-		  "df_inequc_pstruct", false, \
-		  "df_equc_pstruct", false, \
-		  "dfdp_pstruct", false, \
-		  "lbound", [], \
-		  "ubound", [], \
-		  "dfdp", [], \
-		  "cpiv", @ cpiv_bard, \
-		  "max_fract_change", [], \
-		  "fract_prec", [], \
-		  "diffp", [], \
-		  "diff_onesided", [], \
-		  "complex_step_derivative_f", false, \
-		  "complex_step_derivative_inequc", false, \
-		  "complex_step_derivative_equc", false, \
-		  "cstep", cstep_default, \
-		  "fixed", [], \
-		  "inequc", [], \
-		  "equc", [], \
-                  "inequc_f_idx", false, \
-                  "inequc_df_idx", false, \
-                  "equc_f_idx", false, \
-                  "equc_df_idx", false, \
-		  "weights", [], \
-		  "TolFun", stol_default, \
-		  "MaxIter", [], \
-		  "Display", "off", \
-		  "Algorithm", "lm_svd_feasible", \
-		  "plot_cmd", @ (f) 0, \
-		  "debug", false, \
+    p = optimset ("param_config", [], ...
+		  "param_order", [], ...
+		  "param_dims", [], ...
+		  "f_inequc_pstruct", false, ...
+		  "f_equc_pstruct", false, ...
+		  "f_pstruct", false, ...
+		  "df_inequc_pstruct", false, ...
+		  "df_equc_pstruct", false, ...
+		  "df_pstruct", false, ...
+		  "lbound", [], ...
+		  "ubound", [], ...
+		  "dfdp", [], ...
+		  "cpiv", @ cpiv_bard, ...
+		  "max_fract_change", [], ...
+		  "fract_prec", [], ...
+		  "diffp", [], ...
+		  "diff_onesided", [], ...
+		  "complex_step_derivative_f", false, ...
+		  "complex_step_derivative_inequc", false, ...
+		  "complex_step_derivative_equc", false, ...
+		  "cstep", cstep_default, ...
+		  "fixed", [], ...
+		  "inequc", [], ...
+		  "equc", [], ...
+                  "f_inequc_idx", false, ...
+                  "df_inequc_idx", false, ...
+                  "f_equc_idx", false, ...
+                  "df_equc_idx", false, ...
+		  "weights", [], ...
+		  "TolFun", stol_default, ...
+		  "MaxIter", [], ...
+		  "Display", "off", ...
+		  "Algorithm", "lm_svd_feasible", ...
+                  "parallel_local", false, ... # Matlabs UseParallel
+                                # works differently
+		  "plot_cmd", @ (f) 0, ...
+		  "debug", false, ...
 		  "lm_svd_feasible_alt_s", false);
     return;
   endif
@@ -108,10 +110,10 @@ function [p, resid, cvg, outp] = \
   f_inequc_pstruct = optimget (settings, "f_inequc_pstruct", false);
   f_equc_pstruct = optimget (settings, "f_equc_pstruct", false);
   f_pstruct = optimget (settings, "f_pstruct", false);
-  dfdp_pstruct = optimget (settings, "dfdp_pstruct", f_pstruct);
-  df_inequc_pstruct = optimget (settings, "df_inequc_pstruct", \
+  dfdp_pstruct = optimget (settings, "df_pstruct", f_pstruct);
+  df_inequc_pstruct = optimget (settings, "df_inequc_pstruct", ...
 				f_inequc_pstruct);
-  df_equc_pstruct = optimget (settings, "df_equc_pstruct", \
+  df_equc_pstruct = optimget (settings, "df_equc_pstruct", ...
 			      f_equc_pstruct);
   lbound = optimget (settings, "lbound");
   ubound = optimget (settings, "ubound");
@@ -127,21 +129,21 @@ function [p, resid, cvg, outp] = \
   if (do_cstep && ! isempty (dfdp))
     error ("both 'complex_step_derivative_f' and 'dfdp' are set");
   endif
-  do_cstep_inequc = \
+  do_cstep_inequc = ...
       optimget (settings, "complex_step_derivative_inequc", false);
   do_cstep_equc = optimget (settings, "complex_step_derivative_equc", false);
 
-  any_vector_conf = ! (isempty (lbound) && isempty (ubound) && \
-		       isempty (max_fract_change) && \
-		       isempty (fract_prec) && isempty (diffp) && \
+  any_vector_conf = ! (isempty (lbound) && isempty (ubound) && ...
+		       isempty (max_fract_change) && ...
+		       isempty (fract_prec) && isempty (diffp) && ...
 		       isempty (diff_onesided) && isempty (fixed));
 
   ## collect constraints
-  [mc, vc, f_genicstr, df_gencstr, user_df_gencstr] = \
-      __collect_constraints__ (optimget (settings, "inequc"), \
+  [mc, vc, f_genicstr, df_gencstr, user_df_gencstr] = ...
+      __collect_constraints__ (optimget (settings, "inequc"), ...
 			       do_cstep_inequc, "inequality constraints");
-  [emc, evc, f_genecstr, df_genecstr, user_df_genecstr] = \
-      __collect_constraints__ (optimget (settings, "equc"), \
+  [emc, evc, f_genecstr, df_genecstr, user_df_genecstr] = ...
+      __collect_constraints__ (optimget (settings, "equc"), ...
 			       do_cstep_equc, "equality constraints");
   mc_struct = isstruct (mc);
   emc_struct = isstruct (emc);
@@ -151,25 +153,25 @@ function [p, resid, cvg, outp] = \
   if (isempty (dfdp)) dfdp_pstruct = false; endif
   if (isempty (f_genicstr))
     f_inequc_pstruct = false;
-  elseif (! optimget (settings, "inequc_f_idx", false))
-    f_genicstr = @ (p, varargin) apply_idx_if_given \
+  elseif (! optimget (settings, "f_inequc_idx", false))
+    f_genicstr = @ (p, varargin) apply_idx_if_given ...
         (f_genicstr (p, varargin{:}), varargin{:});
   endif
   if (isempty (f_genecstr))
     f_equc_pstruct = false;
-  elseif (! optimget (settings, "equc_f_idx", false))
-    f_genecstr = @ (p, varargin) apply_idx_if_given \
+  elseif (! optimget (settings, "f_equc_idx", false))
+    f_genecstr = @ (p, varargin) apply_idx_if_given ...
         (f_genecstr (p, varargin{:}), varargin{:});
   endif
   if (user_df_gencstr)
-    if (! optimget (settings, "inequc_df_idx", false))
+    if (! optimget (settings, "df_inequc_idx", false))
       df_gencstr = @ (varargin) df_gencstr (varargin{:})(varargin{2}, :);
     endif
   else
     df_inequc_pstruct = false;
   endif
   if (user_df_genecstr)
-    if (! optimget (settings, "equc_df_idx", false))
+    if (! optimget (settings, "df_equc_idx", false))
       df_genecstr = @ (varargin) df_genecstr (varargin{:})(varargin{2}, :);
     endif
   else
@@ -177,20 +179,20 @@ function [p, resid, cvg, outp] = \
   endif
 
   ## some settings require a parameter order
-  if (pin_struct || ! isempty (pconf) || f_inequc_pstruct || \
-      f_equc_pstruct || f_pstruct || dfdp_pstruct || \
-      df_inequc_pstruct || df_equc_pstruct || mc_struct || \
+  if (pin_struct || ! isempty (pconf) || f_inequc_pstruct || ...
+      f_equc_pstruct || f_pstruct || dfdp_pstruct || ...
+      df_inequc_pstruct || df_equc_pstruct || mc_struct || ...
       emc_struct)
     if (isempty (pord))
       if (pin_struct)
-	if (any_vector_conf || \
-	    ! (f_pstruct && \
-	       (f_inequc_pstruct || isempty (f_genicstr)) && \
-	       (f_equc_pstruct || isempty (f_genecstr)) && \
-	       (dfdp_pstruct || isempty (dfdp)) && \
-	       (df_inequc_pstruct || ! user_df_gencstr) && \
-	       (df_equc_pstruct || ! user_df_genecstr) && \
-	       (mc_struct || isempty (mc)) && \
+	if (any_vector_conf || ...
+	    ! (f_pstruct && ...
+	       (f_inequc_pstruct || isempty (f_genicstr)) && ...
+	       (f_equc_pstruct || isempty (f_genecstr)) && ...
+	       (dfdp_pstruct || isempty (dfdp)) && ...
+	       (df_inequc_pstruct || ! user_df_gencstr) && ...
+	       (df_equc_pstruct || ! user_df_genecstr) && ...
+	       (mc_struct || isempty (mc)) && ...
 	       (emc_struct || isempty (emc))))
 	  error ("no parameter order specified and constructing a parameter order from the structure of initial parameters can not be done since not all configuration or given functions are structure based");
 	else
@@ -209,15 +211,15 @@ function [p, resid, cvg, outp] = \
     endif
     if (isempty (pdims))
       if (pin_struct)
-	pdims = cellfun \
+	pdims = cellfun ...
 	    (@ size, fields2cell (pin, pord), "UniformOutput", false);
       else
 	pdims = num2cell (ones (nnames, 2), 2);
       endif
     else
       pdims = pdims(:);
-      if (pin_struct && \
-	  ! all (cellfun (@ (x, y) prod (size (x)) == prod (y), \
+      if (pin_struct && ...
+	  ! all (cellfun (@ (x, y) prod (size (x)) == prod (y), ...
 			  struct2cell (pin), pdims)))
 	error ("given param_dims and dimensions of initial parameters do not match");
       endif
@@ -230,13 +232,13 @@ function [p, resid, cvg, outp] = \
     if (any (pnel > 1))
       pnonscalar = true;
       cpnel = num2cell (pnel);
-      prepidx = cat (1, cellfun \
-		     (@ (x, n) x(ones (1, n), 1), \
-		      num2cell ((1:nnames).'), cpnel, \
+      prepidx = cat (1, cellfun ...
+		     (@ (x, n) x(ones (1, n), 1), ...
+		      num2cell ((1:nnames).'), cpnel, ...
 		      "UniformOutput", false){:});
       epord = pord(prepidx, 1);
-      psubidx = cat (1, cellfun \
-		     (@ (n) (1:n).', cpnel, \
+      psubidx = cat (1, cellfun ...
+		     (@ (n) (1:n).', cpnel, ...
 		      "UniformOutput", false){:});
     else
       pnonscalar = false; # some less expensive interfaces later
@@ -259,7 +261,7 @@ function [p, resid, cvg, outp] = \
 
   plabels = num2cell (num2cell ((1:np).'));
   if (! isempty (pord))
-    plabels = cat (2, plabels, num2cell (epord), \
+    plabels = cat (2, plabels, num2cell (epord), ...
 		   num2cell (num2cell (psubidx)));
   endif
 
@@ -283,7 +285,7 @@ function [p, resid, cvg, outp] = \
 
     ## supplement parameter names lacking in param_config
     nidx = ! isfield (pconf, pord);
-    pconf = cell2fields ({struct()}(ones (1, sum (nidx))), \
+    pconf = cell2fields ({struct()}(ones (1, sum (nidx))), ...
 			 pord(nidx), 2, pconf);
 
     pconf = structcat (1, fields2cell (pconf, pord){:});
@@ -296,9 +298,9 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "lbound"))
       idx = ! fieldempty (pconf, "lbound");
       if (pnonscalar)
-	lbound (idx(prepidx), 1) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).lbound}.', \
+	lbound (idx(prepidx), 1) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).lbound}.', ...
 			     cpnel(idx), "UniformOutput", false){:});
       else
 	lbound(idx, 1) = cat (1, pconf.lbound);
@@ -309,9 +311,9 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "ubound"))
       idx = ! fieldempty (pconf, "ubound");
       if (pnonscalar)
-	ubound (idx(prepidx), 1) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).ubound}.', \
+	ubound (idx(prepidx), 1) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).ubound}.', ...
 			     cpnel(idx), "UniformOutput", false){:});
       else
 	ubound(idx, 1) = cat (1, pconf.ubound);
@@ -323,10 +325,10 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "max_fract_change"))
       idx = ! fieldempty (pconf, "max_fract_change");
       if (pnonscalar)
-	max_fract_change(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).max_fract_change}.', \
-			     cpnel(idx), \
+	max_fract_change(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).max_fract_change}.', ...
+			     cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	max_fract_change(idx) = [pconf.max_fract_change];
@@ -336,9 +338,9 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "fract_prec"))
       idx = ! fieldempty (pconf, "fract_prec");
       if (pnonscalar)
-	fract_prec(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).fract_prec}.', cpnel(idx), \
+	fract_prec(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).fract_prec}.', cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	fract_prec(idx) = [pconf.fract_prec];
@@ -350,9 +352,9 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "diffp"))
       idx = ! fieldempty (pconf, "diffp");
       if (pnonscalar)
-	diffp(idx(prepidx)) = \
-	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     {pconf(idx).diffp}.', cpnel(idx), \
+	diffp(idx(prepidx)) = ...
+	    cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     {pconf(idx).diffp}.', cpnel(idx), ...
 			     "UniformOutput", false){:});
       else
 	diffp(idx) = [pconf.diffp];
@@ -364,10 +366,10 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "diff_onesided"))
       idx = ! fieldempty (pconf, "diff_onesided");
       if (pnonscalar)
-	diff_onesided(idx(prepidx)) = \
-	    logical \
-	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			      {pconf(idx).diff_onesided}.', cpnel(idx), \
+	diff_onesided(idx(prepidx)) = ...
+	    logical ...
+	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			      {pconf(idx).diff_onesided}.', cpnel(idx), ...
 			     "UniformOutput", false){:}));
       else
 	diff_onesided(idx) = logical ([pconf.diff_onesided]);
@@ -377,10 +379,10 @@ function [p, resid, cvg, outp] = \
     if (isfield (pconf, "fixed"))
       idx = ! fieldempty (pconf, "fixed");
       if (pnonscalar)
-	fixed(idx(prepidx)) = \
-	    logical \
-	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			      {pconf(idx).fixed}.', cpnel(idx), \
+	fixed(idx(prepidx)) = ...
+	    logical ...
+	    (cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			      {pconf(idx).fixed}.', cpnel(idx), ...
 			     "UniformOutput", false){:}));
       else
 	fixed(idx) = logical ([pconf.fixed]);
@@ -456,8 +458,8 @@ function [p, resid, cvg, outp] = \
   ## initial parameters
   if (pin_struct)
     if (pnonscalar)
-      pin = cat (1, cellfun (@ (x, n) reshape (x, n, 1), \
-			     fields2cell (pin, pord), cpnel, \
+      pin = cat (1, cellfun (@ (x, n) reshape (x, n, 1), ...
+			     fields2cell (pin, pord), cpnel, ...
 			     "UniformOutput", false){:});
     else
       pin = cat (1, fields2cell (pin, pord){:});
@@ -467,13 +469,13 @@ function [p, resid, cvg, outp] = \
   ## model function
   if (f_pstruct)
     if (pnonscalar)
-      f = @ (p, varargin) \
-	  f (cell2struct \
-	     (cellfun (@ reshape, mat2cell (p, ppartidx), \
-		       pdims, "UniformOutput", false), \
+      f = @ (p, varargin) ...
+	  f (cell2struct ...
+	     (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+		       pdims, "UniformOutput", false), ...
 	      pord, 1), varargin{:});
     else
-      f = @ (p, varargin) \
+      f = @ (p, varargin) ...
 	  f (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -496,19 +498,19 @@ function [p, resid, cvg, outp] = \
   endif
   if (dfdp_pstruct)
     if (pnonscalar)
-      dfdp = @ (p, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (dfdp (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
-		       pord, 1), hook), \
+      dfdp = @ (p, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (dfdp (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
+		       pord, 1), hook), ...
 		pord){:});
     else
-      dfdp = @ (p, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (dfdp (cell2struct (num2cell (p), pord, 1), hook), \
+      dfdp = @ (p, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (dfdp (cell2struct (num2cell (p), pord, 1), hook), ...
 		pord){:});
     endif
   endif
@@ -516,14 +518,14 @@ function [p, resid, cvg, outp] = \
   ## function for general inequality constraints
   if (f_inequc_pstruct)
     if (pnonscalar)
-      f_genicstr = @ (p, varargin) \
-	  f_genicstr (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
+      f_genicstr = @ (p, varargin) ...
+	  f_genicstr (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
 		       pord, 1), varargin{:});
     else
-      f_genicstr = @ (p, varargin) \
-	  f_genicstr \
+      f_genicstr = @ (p, varargin) ...
+	  f_genicstr ...
 	  (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -534,21 +536,21 @@ function [p, resid, cvg, outp] = \
   ## jacobian of general inequality constraints
   if (df_inequc_pstruct)
     if (pnonscalar)
-      df_gencstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_gencstr \
-		(cell2struct \
-		 (cellfun (@ reshape, mat2cell (p, ppartidx), \
-			   pdims, "UniformOutput", false), pord, 1), \
-		 func, idx, hook), \
+      df_gencstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_gencstr ...
+		(cell2struct ...
+		 (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+			   pdims, "UniformOutput", false), pord, 1), ...
+		 func, idx, hook), ...
 		pord){:});
     else
-      df_gencstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_gencstr (cell2struct (num2cell (p), pord, 1), \
-			    func, idx, hook), \
+      df_gencstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_gencstr (cell2struct (num2cell (p), pord, 1), ...
+			    func, idx, hook), ...
 		pord){:});
     endif
   endif
@@ -556,14 +558,14 @@ function [p, resid, cvg, outp] = \
   ## function for general equality constraints
   if (f_equc_pstruct)
     if (pnonscalar)
-      f_genecstr = @ (p, varargin) \
-	  f_genecstr (cell2struct \
-		      (cellfun (@ reshape, mat2cell (p, ppartidx), \
-				pdims, "UniformOutput", false), \
+      f_genecstr = @ (p, varargin) ...
+	  f_genecstr (cell2struct ...
+		      (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+				pdims, "UniformOutput", false), ...
 		       pord, 1), varargin{:});
     else
-      f_genecstr = @ (p, varargin) \
-	  f_genecstr \
+      f_genecstr = @ (p, varargin) ...
+	  f_genecstr ...
 	  (cell2struct (num2cell (p), pord, 1), varargin{:});
     endif
   endif
@@ -574,21 +576,21 @@ function [p, resid, cvg, outp] = \
   ## jacobian of general equality constraints
   if (df_equc_pstruct)
     if (pnonscalar)
-      df_genecstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_genecstr \
-		(cell2struct \
-		 (cellfun (@ reshape, mat2cell (p, ppartidx), \
-			   pdims, "UniformOutput", false), pord, 1), \
-		 func, idx, hook), \
+      df_genecstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_genecstr ...
+		(cell2struct ...
+		 (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+			   pdims, "UniformOutput", false), pord, 1), ...
+		 func, idx, hook), ...
 		pord){:});
     else
-      df_genecstr = @ (p, func, idx, hook) \
-	  cat (2, \
-	       fields2cell \
-	       (df_genecstr (cell2struct (num2cell (p), pord, 1), \
-			     func, idx, hook), \
+      df_genecstr = @ (p, func, idx, hook) ...
+	  cat (2, ...
+	       fields2cell ...
+	       (df_genecstr (cell2struct (num2cell (p), pord, 1), ...
+			     func, idx, hook), ...
 		pord){:});
     endif
   endif
@@ -618,29 +620,29 @@ function [p, resid, cvg, outp] = \
   ## parameter-related configuration for jacobian functions
   if (dfdp_pstruct || df_inequc_pstruct || df_equc_pstruct)
     if(pnonscalar)
-      s_diffp = cell2struct \
-	  (cellfun (@ reshape, mat2cell (diffp, ppartidx), \
+      s_diffp = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (diffp, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_diff_onesided = cell2struct \
-	  (cellfun (@ reshape, mat2cell (diff_onesided, ppartidx), \
+      s_diff_onesided = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (diff_onesided, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_lbound = cell2struct \
-	  (cellfun (@ reshape, mat2cell (lbound, ppartidx), \
+      s_orig_lbound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (lbound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_orig_ubound = cell2struct \
-	  (cellfun (@ reshape, mat2cell (ubound, ppartidx), \
+      s_orig_ubound = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (ubound, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
-      s_plabels = cell2struct \
-	  (num2cell \
-	   (cat (2, cellfun \
-		 (@ (x) cellfun \
-		  (@ reshape, mat2cell (cat (1, x{:}), ppartidx), \
-		   pdims, "UniformOutput", false), \
-		  num2cell (plabels, 1), "UniformOutput", false){:}), \
-	    2), \
+      s_plabels = cell2struct ...
+	  (num2cell ...
+	   (cat (2, cellfun ...
+		 (@ (x) cellfun ...
+		  (@ reshape, mat2cell (cat (1, x{:}), ppartidx), ...
+		   pdims, "UniformOutput", false), ...
+		  num2cell (plabels, 1), "UniformOutput", false){:}), ...
+	    2), ...
 	   pord, 1);
-      s_orig_fixed = cell2struct \
-	  (cellfun (@ reshape, mat2cell (fixed, ppartidx), \
+      s_orig_fixed = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (fixed, ppartidx), ...
 		    pdims, "UniformOutput", false), pord, 1);
     else
       s_diffp = cell2struct (num2cell (diffp), pord, 1);
@@ -726,6 +728,7 @@ function [p, resid, cvg, outp] = \
   endif
 
   #### collect remaining settings
+  parallel_local = optimget (settings, "parallel_local", false);
   hook.MaxIter = optimget (settings, "MaxIter");
   if (ischar (hook.cpiv = optimget (settings, "cpiv", @ cpiv_bard)))
     hook.cpiv = str2func (hook.cpiv);
@@ -749,32 +752,32 @@ function [p, resid, cvg, outp] = \
   nonfixed = ! fixed;
   if (any (fixed))
     ## backend (returned values and initial parameters)
-    backend = @ (f, pin, hook) \
+    backend = @ (f, pin, hook) ...
 	backend_wrapper (backend, fixed, f, pin, hook);
 
     ## model function
     f = @ (p, varargin) f (assign (pin, nonfixed, p), varargin{:});
 
     ## jacobian of model function
-    dfdp = @ (p, hook) \
+    dfdp = @ (p, hook) ...
 	dfdp (assign (pin, nonfixed, p), hook)(:, nonfixed);
     
     ## function for general inequality constraints
-    f_genicstr = @ (p, varargin) \
+    f_genicstr = @ (p, varargin) ...
 	f_genicstr (assign (pin, nonfixed, p), varargin{:});
     
     ## jacobian of general inequality constraints
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (assign (pin, nonfixed, p), func, idx, hook) \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (assign (pin, nonfixed, p), func, idx, hook) ...
 	(:, nonfixed);
 
     ## function for general equality constraints
-    f_genecstr = @ (p, varargin) \
+    f_genecstr = @ (p, varargin) ...
 	f_genecstr (assign (pin, nonfixed, p), varargin{:});
 
     ## jacobian of general equality constraints
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (assign (pin, nonfixed, p), func, idx, hook) \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (assign (pin, nonfixed, p), func, idx, hook) ...
 	(:, nonfixed);
 
     ## linear inequality constraints
@@ -798,67 +801,72 @@ function [p, resid, cvg, outp] = \
 
   ## jacobian of model function
   if (dfdp_pstruct)
-    dfdp = @ (p, hook) \
-	dfdp (p, cell2fields \
-	      ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		s_orig_ubound, s_plabels, \
-		cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-			    1, s_orig_fixed), cstep}, \
-	       {"diffp", "diff_onesided", "lbound", "ubound", \
-		"plabels", "fixed", "h"}, \
+    dfdp = @ (p, hook) ...
+	dfdp (p, cell2fields ...
+	      ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		s_orig_ubound, s_plabels, ...
+		cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+			    1, s_orig_fixed), ...
+                cstep, parallel_local}, ...
+	       {"diffp", "diff_onesided", "lbound", "ubound", ...
+		"plabels", "fixed", "h", "parallel_local"}, ...
 	       2, hook));
   else
-    dfdp = @ (p, hook) \
-	dfdp (p, cell2fields \
-	      ({diffp, diff_onesided, orig_lbound, orig_ubound, \
-		plabels, assign(orig_fixed, nonfixed, hook.fixed), \
-		cstep}, \
-	       {"diffp", "diff_onesided", "lbound", "ubound", \
-		"plabels", "fixed", "h"}, \
+    dfdp = @ (p, hook) ...
+	dfdp (p, cell2fields ...
+	      ({diffp, diff_onesided, orig_lbound, orig_ubound, ...
+		plabels, assign(orig_fixed, nonfixed, hook.fixed), ...
+		cstep, parallel_local}, ...
+	       {"diffp", "diff_onesided", "lbound", "ubound", ...
+		"plabels", "fixed", "h", "parallel_local"}, ...
 	       2, hook));
   endif
 
   ## jacobian of general inequality constraints
   if (df_inequc_pstruct)
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (p, func, idx, cell2fields \
-		    ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		      s_orig_ubound, s_plabels, \
-		      cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-				  1, s_orig_fixed), cstep}, \
-		     {"diffp", "diff_onesided", "lbound", "ubound", \
-		      "plabels", "fixed", "h"}, \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (p, func, idx, cell2fields ...
+		    ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		      s_orig_ubound, s_plabels, ...
+		      cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+				  1, s_orig_fixed), ...
+                      cstep, parallel_local}, ...
+		     {"diffp", "diff_onesided", "lbound", "ubound", ...
+		      "plabels", "fixed", "h", "parallel_local"}, ...
 		     2, hook));
   else
-    df_gencstr = @ (p, func, idx, hook) \
-	df_gencstr (p, func, idx, cell2fields \
-		    ({diffp, diff_onesided, orig_lbound, \
-		      orig_ubound, plabels, \
-		      assign(orig_fixed, nonfixed, hook.fixed), cstep}, \
-		     {"diffp", "diff_onesided", "lbound", "ubound", \
-		      "plabels", "fixed", "h"}, \
+    df_gencstr = @ (p, func, idx, hook) ...
+	df_gencstr (p, func, idx, cell2fields ...
+		    ({diffp, diff_onesided, orig_lbound, ...
+		      orig_ubound, plabels, ...
+		      assign(orig_fixed, nonfixed, hook.fixed), ...
+                      cstep, parallel_local}, ...
+		     {"diffp", "diff_onesided", "lbound", "ubound", ...
+		      "plabels", "fixed", "h", "parallel_local"}, ...
 		     2, hook));
   endif
 
   ## jacobian of general equality constraints
   if (df_equc_pstruct)
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (p, func, idx, cell2fields \
-		     ({s_diffp, s_diff_onesided, s_orig_lbound, \
-		       s_orig_ubound, s_plabels, \
-		       cell2fields(num2cell(hook.fixed), pord(nonfixed), \
-				   1, s_orig_fixed), cstep}, \
-		      {"diffp", "diff_onesided", "lbound", "ubound", \
-		       "plabels", "fixed", "h"}, \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (p, func, idx, cell2fields ...
+		     ({s_diffp, s_diff_onesided, s_orig_lbound, ...
+		       s_orig_ubound, s_plabels, ...
+		       cell2fields(num2cell(hook.fixed), pord(nonfixed), ...
+				   1, s_orig_fixed), ...
+                       cstep, parallel_local}, ...
+		      {"diffp", "diff_onesided", "lbound", "ubound", ...
+		       "plabels", "fixed", "h", "parallel_local"}, ...
 		      2, hook));
   else
-    df_genecstr = @ (p, func, idx, hook) \
-	df_genecstr (p, func, idx, cell2fields \
-		     ({diffp, diff_onesided, orig_lbound, \
-		       orig_ubound, plabels, \
-		       assign(orig_fixed, nonfixed, hook.fixed), cstep}, \
-		      {"diffp", "diff_onesided", "lbound", "ubound", \
-		       "plabels", "fixed", "h"}, \
+    df_genecstr = @ (p, func, idx, hook) ...
+	df_genecstr (p, func, idx, cell2fields ...
+		     ({diffp, diff_onesided, orig_lbound, ...
+		       orig_ubound, plabels, ...
+		       assign(orig_fixed, nonfixed, hook.fixed), ...
+                       cstep, parallel_local}, ...
+		      {"diffp", "diff_onesided", "lbound", "ubound", ...
+		       "plabels", "fixed", "h", "parallel_local"}, ...
 		      2, hook));
   endif
 
@@ -881,41 +889,41 @@ function [p, resid, cvg, outp] = \
     if (n_genicstr > 0)
       nidxi = 1 : n_genicstr;
       nidxe = n_genicstr + 1 : n_genicstr + n_genecstr;
-      f_gencstr = @ (p, idx, varargin) \
-	  cat (1, \
-	       f_genicstr (p, idx(nidxi), varargin{:}), \
+      f_gencstr = @ (p, idx, varargin) ...
+	  cat (1, ...
+	       f_genicstr (p, idx(nidxi), varargin{:}), ...
 	       f_genecstr (p, idx(nidxe), varargin{:}));
-      df_gencstr = @ (p, idx, hook) \
-	  cat (1, \
-	       df_gencstr (p, @ (p, varargin) \
-			   possibly_pstruct_f_genicstr \
-			   (p, idx(nidxi), varargin{:}), \
-			   idx(nidxi), \
-			   setfield (hook, "f", \
-				     hook.f(nidxi(idx(nidxi))))), \
-	       df_genecstr (p, @ (p, varargin) \
-			    possibly_pstruct_f_genecstr \
-			    (p, idx(nidxe), varargin{:}), \
-			    idx(nidxe), \
-			    setfield (hook, "f", \
+      df_gencstr = @ (p, idx, hook) ...
+	  cat (1, ...
+	       df_gencstr (p, @ (p, varargin) ...
+			   possibly_pstruct_f_genicstr ...
+			   (p, idx(nidxi), varargin{:}), ...
+			   idx(nidxi), ...
+			   setfield (hook, "f", ...
+				     hook.f(nidxi(idx(nidxi))))), ...
+	       df_genecstr (p, @ (p, varargin) ...
+			    possibly_pstruct_f_genecstr ...
+			    (p, idx(nidxe), varargin{:}), ...
+			    idx(nidxe), ...
+			    setfield (hook, "f", ...
 				      hook.f(nidxe(idx(nidxe))))));
     else
       f_gencstr = f_genecstr;
-      df_gencstr = @ (p, idx, hook) \
-	  df_genecstr (p, \
-		       @ (p, varargin) \
-		       possibly_pstruct_f_genecstr \
-		       (p, idx, varargin{:}), \
-		       idx, \
+      df_gencstr = @ (p, idx, hook) ...
+	  df_genecstr (p, ...
+		       @ (p, varargin) ...
+		       possibly_pstruct_f_genecstr ...
+		       (p, idx, varargin{:}), ...
+		       idx, ...
 		       setfield (hook, "f", hook.f(idx)));
     endif
   else
     f_gencstr = f_genicstr;
-    df_gencstr = @ (p, idx, hook) \
-	df_gencstr (p, \
-		    @ (p, varargin) \
-		    possibly_pstruct_f_genicstr (p, idx, varargin{:}), \
-		    idx, \
+    df_gencstr = @ (p, idx, hook) ...
+	df_gencstr (p, ...
+		    @ (p, varargin) ...
+		    possibly_pstruct_f_genicstr (p, idx, varargin{:}), ...
+		    idx, ...
 		    setfield (hook, "f", hook.f(idx)));
   endif    
   n_gencstr = n_genicstr + n_genecstr;
@@ -925,15 +933,15 @@ function [p, resid, cvg, outp] = \
   if (n_gencstr > 0)
     nidxl = 1:n_lincstr;
     nidxh = n_lincstr + 1 : n_lincstr + n_gencstr;
-    f_cstr = @ (p, idx, varargin) \
-	cat (1, \
-	     mc(:, idx(nidxl)).' * p + vc(idx(nidxl), 1), \
+    f_cstr = @ (p, idx, varargin) ...
+	cat (1, ...
+	     mc(:, idx(nidxl)).' * p + vc(idx(nidxl), 1), ...
 	     f_gencstr (p, idx(nidxh), varargin{:}));
-    df_cstr = @ (p, idx, hook) \
-	cat (1, \
-	     mc(:, idx(nidxl)).', \
-	     df_gencstr (p, idx(nidxh), \
-			 setfield (hook, "f", \
+    df_cstr = @ (p, idx, hook) ...
+	cat (1, ...
+	     mc(:, idx(nidxl)).', ...
+	     df_gencstr (p, idx(nidxh), ...
+			 setfield (hook, "f", ...
 				   hook.f(nidxh))));
   else
     f_cstr = @ (p, idx, varargin) mc(:, idx).' * p + vc(idx, 1);
@@ -985,9 +993,9 @@ function [p, resid, cvg, outp] = \
 
   if (pin_struct)
     if (pnonscalar)
-      p = cell2struct \
-	  (cellfun (@ reshape, mat2cell (p, ppartidx), \
-		    pdims, "UniformOutput", false), \
+      p = cell2struct ...
+	  (cellfun (@ reshape, mat2cell (p, ppartidx), ...
+		    pdims, "UniformOutput", false), ...
 	   pord, 1);
     else
       p = cell2struct (num2cell (p), pord, 1);
