@@ -1,4 +1,4 @@
-## Copyright (C) 2011 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2011-2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -51,8 +51,8 @@
 ## non-scalar, parameters and flagging parameters as fixed are possible.
 ## The following settings have the same meaning as in
 ## @code{nonlin_residmin} (please refer to there): @code{param_order},
-## @code{param_dims}, @code{f_pstruct}, @code{dfdp_pstruct},
-## @code{diffp}, @code{diff_onesided}, @code{complex_step_derivative},
+## @code{param_dims}, @code{f_pstruct}, @code{df_pstruct},
+## @code{diffp}, @code{diff_onesided}, @code{complex_step_derivative_f},
 ## @code{cstep}, @code{fixed}, and @code{weights}. Similarly,
 ## @code{param_config} can be used, but only with fields corresponding
 ## to the settings @code{fixed}, @code{diffp}, and @code{diff_onesided}.
@@ -63,20 +63,21 @@
 ## Users may pass information on the result of the optimization in
 ## @code{residuals} (self-explaining) and @code{covd} (covariance matrix
 ## of data). In many cases the type of objective function of the
-## optimization must be specified in @code{objf}; currently, there is
-## only a backend for the type "wls" (weighted least squares).
+## optimization must be specified in @code{objf_type}; currently, there
+## is only a backend for the type "wls" (weighted least squares).
 ##
 ## Backend-specific information
 ##
-## The backend for @code{objf == "wls"} (currently the only backend)
-## computes @code{cord} (due to user request or as a prerequisite for
-## @code{covp} and @code{corp}) as a diagonal matrix by assuming that
-## the variances of data points are proportional to the reciprocal of
-## the squared @code{weights} and guessing the factor of proportionality
-## from the residuals. If @code{covp} is not defined (e.g. because the
-## Jacobian has no full rank), it makes an attempt to still compute its
-## uniquely defined elements, if any, and to find the additional defined
-## elements (being @code{1} or @code{-1}), if any, in @code{corp}.
+## The backend for @code{objf_type == "wls"} (currently the only
+## backend) computes @code{covd} (due to user request or as a
+## prerequisite for @code{covp} and @code{corp}) as a diagonal matrix by
+## assuming that the variances of data points are proportional to the
+## reciprocal of the squared @code{weights} and guessing the factor of
+## proportionality from the residuals. If @code{covp} is not defined
+## (e.g. because the Jacobian has no full rank), it makes an attempt to
+## still compute its uniquely defined elements, if any, and to find the
+## additional defined elements (being @code{1} or @code{-1}), if any, in
+## @code{corp}.
 ##
 ## @seealso {curvefit_stat}
 ## @end deftypefn
